@@ -37,7 +37,7 @@ sub run_tests {
     my $cmp_pkg   = 'RPC::ExtDirect::Test::Util';
     my $num_tests = @run_only || @$tests;
     
-    plan tests => 4 * $num_tests;
+    plan tests => 5 * $num_tests;
 
     TEST:
     for my $test ( @$tests ) {
@@ -65,21 +65,28 @@ sub run_tests {
         my $page = $ct->$method($url, $req);
 
         if ( ok $page, "$name not empty" ) {
-            my $want_type = $output->{content_type};
-            my $have_type = $page->content_type();
-            
-            like $have_type, $want_type, "$name content type";
-            
             my $want_status = $output->{status};
             my $have_status = $page->is_ok() ? 200 : $page->error_code();
 
-            is $have_status, $want_status, "$name HTTP status";
+            is $have_status, $want_status, "$name: HTTP status";
 
+            my $want_type = $output->{content_type};
+            my $have_type = $page->content_type();
+            
+            like $have_type, $want_type, "$name: content type";
+
+            my $want_len = defined $output->{cgi_content_length}
+                         ? $output->{cgi_content_length}
+                         : $output->{content_length};
+            my $have_len = $page->content_length();
+
+            is $have_len, $want_len, "$name: content length";
+            
             my $cmp_fn = $output->{comparator};
             my $want   = $output->{cgi_content} || $output->{content};
             my $have   = $page->raw_content();
             
-            $cmp_pkg->$cmp_fn($have, $want, "$name content")
+            $cmp_pkg->$cmp_fn($have, $want, "$name: content")
                 or diag explain "Page: ", $page;
 
             $page->delete();
